<?php

require('evteam-config-generator.php');
require('connection-cfg-generator.php');
require('link-generator.php');


function create_config($connDetails, $redundancy) {
    $ip_key = ($redundancy === 'primary') ? 'primaryIp' : 'secondaryIp';
    $team_prefix = ($redundancy === 'primary') ? 'team' : 'F_team';

    return [
        'coreIp' => $connDetails['coreRouters'][$ip_key],
        'name' => $connDetails['basics']['name'],
        'id' => $connDetails['basics']['eviewId'],
        'asset' => $connDetails['basics']['deviceAsset'],
        'redundancy' => $redundancy,
        'wan' => [
            'interface' => $connDetails['wan']['interface'],
            'ip' => $connDetails['wan']['ip'],
            'subnet' => $connDetails['wan']['subnet']
        ],
        'team' => [
            'name' => $team_prefix . ( get_last_team($redundancy) + 1),
            'ip' => [
                'evx' => $connDetails['teams'][$redundancy]['teamIpEvx'],
                'core' => $connDetails['teams'][$redundancy]['teamIpCore']
            ],
        ],
        'links' => set_link_details($connDetails['links'], $redundancy)
    ];
}

function create_primary_config($connDetails)
{
    return create_config($connDetails, "primary");
}

function create_secondary_config($connDetails)
{
    return create_config($connDetails, "secondary");
}

function create_temp_directories($connDetails)
{
    $args = $connDetails['team']['name'] . " " . count($connDetails['links']);
    $err = run_shell_script('../../scripts/createTempDirectories', $args);
    $err = check_error_state($err, 'creating config directories');
    if (!$err['success']) {
        throw new Exception('Failed to create directories');
    };

    return true;
}

function create_files($teamDetails){
    try{
        create_temp_directories($teamDetails);
        create_evteam_conf_file($teamDetails);
        create_connection_config($teamDetails);
        create_link_config_files($teamDetails);
        return true;
    } catch (Exception $e) {
        throw $e;
    }
}

function create_evteam_conf_file($connDetails)
{
    $links = array_map(function($link){
        return $link['name'];
    },$connDetails['links'] );
    $config = create_evteam_conf($connDetails['team']['name'],$links,"evx");
    if (!write_conf($config, "evx")) {
        throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' evx evteam config');
    }

    $config = create_evteam_conf($connDetails['team']['name'],$links,"core");
    if (!write_conf($config, "core")) {
        throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' core evteam config');
    }

    return true;
}

function create_connection_config($connDetails){
    $config = create_connection_cfg($connDetails);
    if (!write_cfg($connDetails['team']['name'],$config, "evx")) {
        throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' evx connection config');
    }

    if (!write_cfg($connDetails['team']['name'],$config, "core")) {
        throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' core connection config');
    }

    return  true;
}

function create_link_config_files($connDetails)
{
    foreach ($connDetails['links'] as $link){
        $config = create_link_config($link);
        if (!write_link_cfg($connDetails['team']['name'], $link['port'],$config, "evx")) {
            throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' Link ' . $link['port'],$config . 'evx config');
        }
        if (!write_link_cfg($connDetails['team']['name'], $link['port'],$config, "core")) {
            throw new Exception('Failed to create ' . $connDetails['team']['name'] . ' Link ' . $link['port'],$config . ' core config');
        }
    }

    return [
        'success' => true
    ];
}
