<?php

function get_core_data($redundancy, $ip)
{
    $script = "../../scripts/GetCoreData";
    $coreDetails = array_to_string([$redundancy, $ip]);
    $msg = run_shell_script($script, $coreDetails);

    return check_error_state($msg, "Getting Core Details");
}

function get_last_entry($file)
{
    $line = '';

    $f = fopen($file, 'r');
    $cursor = -1;

    fseek($f, $cursor, SEEK_END);
    $char = fgetc($f);

    /**
     * Trim trailing newline chars of the file
     */
    while ($char === "\n" || $char === "\r") {
        fseek($f, $cursor--, SEEK_END);
        $char = fgetc($f);
    }

    /**
     * Read until the start of file or first newline char
     */
    while ($char !== false && $char !== "\n" && $char !== "\r") {
        /**
         * Prepend the new char
         */
        $line = $char . $line;
        fseek($f, $cursor--, SEEK_END);
        $char = fgetc($f);
    }
    
    return $line;
}

function get_last_team($redundancy)
{
    $lastTeam = get_last_entry('../../temp/' . $redundancy . '/teamlist');

    return preg_replace("/[^0-9,.]/", "", $lastTeam);
}

function get_last_tap($redundancy)
{
    $lastTap = get_last_entry('../../temp/' . $redundancy . '/taplist');

    return preg_replace("/[^0-9,.]/", "", $lastTap);
}

function get_last_udp($redundancy)
{
    return get_last_entry('../../temp/' . $redundancy . '/udplist');
}

function check_current_details($conn)
{
    get_core_data($conn['redundancy'], $conn['coreIp']);
    $coreDetails = [
        'lastTeam' => get_last_team($conn['redundancy']),
        'lastTap' => get_last_tap($conn['redundancy']),
        'lastUdp' => get_last_udp($conn['redundancy'])
    ];

    $conn['team']['name'] = check_team_name($conn['team']['name'], $coreDetails['lastTeam']);
    $conn['links'] = check_first_link_no($conn['links'], $coreDetails['lastTap']);
    $conn['links'] = check_first_link_udp($conn['links'], $coreDetails['lastUdp']);

    return $conn;
}

function check_team_name($teamName, $lastTeam){
    $teamNo = preg_replace("/[^0-9,.]/", "", $teamName);
    if ($teamNo <= $lastTeam) {
        return  preg_replace('/[0-9]+/', '', $teamName) . ($lastTeam + 1 );
    }
    return $teamName;
}

function check_first_link_no($links, $lastTap) {
    $firstTapNo = preg_replace("/[^0-9,.]/", "", $links[0]['name']);
    if ($firstTapNo <= $lastTap) {
        $links = array_map(function($link){
            $link['name'] = preg_replace('/[0-9]+/', '', $link['name']) . ($lastTap + $link['port']);
            return $link;
        },$links);

        return $links;
    }

    return $links;
}

function check_first_link_udp($links, $lastUdp) {

    $firstUdp = $links[0]['udp'];
    if ($firstUdp <= $lastUdp) {
        $links = array_map(function($link){
            $link['udp'] = ($lastUdp + $link['port']);
            return $link;
        },$links);
    }

    return $links;
}
