<?php

function send_config_to_core($conn)
{
    $script = '../../scripts/sendTeamConfigToCore';
    $args = array_to_string([ $conn['coreIp'], $conn['team']['name'] ]);
    $msg = run_shell_script($script, $args);
    $msg = check_error_state($msg, 'error sending ' . $conn['team']['name'] . ' config to core router');
    if (!$msg['success']) {
        throw new Exception($msg['error']);
    }

    return true;
}

function create_openvpn_configs($conn)
{
    $script = '../../scripts/createOpenvpnConfig';

    foreach ($conn['links'] as $link) {
        $args = [
            'team' => $conn['team']['name'],
            'link' => 'port' . $link['port'],
            'tap' => $link['name'],
            'udp' => $link['udp'],
            'coreip' => $conn['coreIp']
        ];

        $args = array_to_string($args);
        $msg = run_shell_script($script, $args);
        $msg = check_error_state($msg, 'error creating ' . $link['name'] . ' openvpn config');
        if (!$msg['success']) {
            throw new Exception($msg['error']);
        }
    }
    
    return true;
}

function update_core_acl_team($conn)
{
    $script = '../../scripts/updateTeamCoreACL';
    $args = [
        'coreIp' => $conn['coreIp'],
        'evxTeamIp' => $conn['team']['ip']['evx']
    ];
    $args = array_to_string($args);
    $msg = run_shell_script($script, $args);
    $msg = check_error_state($msg, 'error updating ACL for  ' . $conn['team']['name']);
    if (!$msg['success']) {
        throw new Exception($msg['error']);
    }

    return true;
}

function update_core_acl_links($conn)
{
    $script = '../../scripts/updateLinkCoreACL';
    foreach ($conn['links'] as $link) {
        $args = [
            'coreIp' => $conn['coreIp'],
            'udp' => $link['udp'],
            'tap' => $link['name']
        ];
        $args = array_to_string($args);
        $msg = run_shell_script($script, $args);
        $msg = check_error_state($msg, 'error updating ACL for  ' . $link['name']);
        if (!$msg['success']) {
            throw new Exception($msg['error']);
        }
    }

    return true;
}

function update_core_bgp($conn)
{
    $script = '../../scripts/updateCoreBGP';
    $args = [
        'coreIp' => $conn['coreIp'],
        'redundancy' => $conn['redundancy'],
        'connId' => $conn['id'],
        'evxTeamIp' => $conn['team']['ip']['evx'],
        'wanNetworkIp' => get_network_ip($conn['wan']['ip'], $conn['wan']['subnet']),
        'cidr' => '/' . mask2cidr($conn['wan']['subnet'])
    ];
    $args = array_to_string($args);
    $msg = run_shell_script($script, $args);
    $msg = check_error_state($msg, 'error updating BGP for  ' . $conn['team']['name'] . 'on the core router');
    if (!$msg['success']) {
        throw new Exception($msg['error']);
    }

    return true;
}

function start_team_on_core($conn)
{
    start_tunnels_on_core($conn);
    $script = '../../scripts/startCoreTeam';
    $args = [
        'teamName' => $conn['team']['name'],
        'coreIp' => $conn['coreIp']
    ];
    $args = array_to_string($args);
    $msg = run_shell_script($script, $args);
    $msg = check_error_state($msg, 'error starting  ' . $conn['team']['name'] . ' on core router');
    if (!$msg['success']) {
        throw new Exception($msg['error']);
    }

    return true;
}

function start_tunnels_on_core($conn)
{
    $script = '../../scripts/coreStartLink';
    foreach ($conn['links'] as $link) {
        $args = [
            'tap' => $link['name'],
            'coreIp' => $conn['coreIp']
        ];
        $args = array_to_string($args);
        $msg = run_shell_script($script, $args);
        $msg = check_error_state($mesg, 'error starting  ' . $link['name'] . ' on core router');
        if (!$msg['success']) {
            throw new Exception($msg['error']);
        }
    }

    return true;
}

function update_core_inuse_link_data($conn){
    $script = '../../scripts/updateKnownLinks';
    foreach ($conn['links'] as $link) {
        $args = [
            'tapName' => $link['name'],
            'udp' => $link['udp'],
            'redundancy' => $conn['redundancy'],
            'coreIp' => $conn['coreIp']
        ];
        $args = array_to_string($args);
        $msg = run_shell_script($script, $args);
        $msg = check_error_state($mesg, 'error updating known udp and tap lists on core router');
        if (!$msg['success']) {
            throw new Exception($msg['error']);
        }
    }

    return true;
}

function update_core_inuse_team_data($conn)
{
    $script = '../../scripts/updateKnownTeams';
    $args = [
        'teamName' => $conn['team']['name'],
        'redundancy' => $conn['redundancy'],
        'coreIp' => $conn['coreIp']
    ];
    $args = array_to_string($args);
        $msg = run_shell_script($script, $args);
        $msg = check_error_state($mesg, 'error updating known team lists on core router');
        if (!$msg['success']) {
            throw new Exception($msg['error']);
        }
        
    return true;
}
