const API_BASE = location.host === "localhost:8080" ? "/api/dummy" : "/api";

function requestLoadStateManager(requestPromise, storeKeyName) {
  setLoadState(storeKeyName, LOAD_STATES.REQUESTED);

  return requestPromise
    .then(response => {
      const { success, payload } = response.data;

      // Server should reply with a non 200 code on error
      // So success should always be true
      if (success === false) {
        throw { response };
      }

      setLoadState(storeKeyName, LOAD_STATES.LOADED);
      return payload;
    })
    .catch(err => {
      const { response } = err;
      let errorState = err;

      if (
        response !== undefined &&
        response.data !== undefined &&
        response.data.error !== undefined
      ) {
        const data = response.data;
        errorState = data.error;
      } else if (
        response !== undefined &&
        response.status !== undefined &&
        response.statusText !== undefined
      ) {
        errorState = {
          code: response.status,
          message: `Server Error - ${response.statusText}`
        };
      }

      console.error(errorState);

      setLoadState(storeKeyName, LOAD_STATES.LOAD_ERROR, errorState);

      throw err;
    });
}

const getResource = ({ name, url, params }) =>
  requestLoadStateManager(axios.get(url, { params }), name);

const postResource = ({ name, url, data }) =>
  requestLoadStateManager(axios.post(url, data), name);

function getDeviceInfo() {
  return getResource({
    name: "device",
    url: API_BASE + "/get-device-info.php"
  })
    .then(device => (STORE.device = device))
}

function getPrimaryCoreDetails(ip) {
  return getResource({
    name: "primaryCore",
    url: API_BASE + "/get-core-info.php",
    params: {
      redundancy: "primary",
      ip
    }
  }).then(primaryCore => (STORE.primaryCore = primaryCore));
}

function getSecondaryCoreDetails(ip) {
  return getResource({
    name: "secondaryCore",
    url: API_BASE + "/get-core-info.php",
    params: {
      redundancy: "secondary",
      ip
    }
  }).then(secondaryCore => (STORE.secondaryCore = secondaryCore));
}

function getPreparedConfig(connection) {
  return postResource({
    name: "preparedConfig",
    url: API_BASE + "/get-conn-info.php",
    data: {
      connection
    }
  }).then(payload => {
    STORE.preparedConfig = payload;
  });
}

function actionProvisionDevice(preparedConfig) {
  return postResource({
    name: "provision",
    url: API_BASE + "/create-config.php",
    data: preparedConfig
  });
}

function alwaysFail(storeName) {
  return getResource({
    name: storeName,
    url: API_BASE + "/always-fail.php"
  });
}
