const app = new Vue({
  el: "#app",
  data: {
    store: STORE,
    debug: false
  },
  template: `
    <div>
      <div v-if="store.develop" class="row">
        <div class="col-md-4">
          <div class="checkbox">
            <label>
              <input type="checkbox" v-model="debug"> Debug
            </label>
          </div>

          <div class="checkbox">
            <label>
              <input type="checkbox" v-model="store.disableValidation"> Disable Validation
            </label>
          </div>
        </div>

        <div class="col-md-4">
          <a class="btn btn-default" @click="setDummyConnectionData">Load dummy data</a>
        </div>
        <div class="col-md-4">
          <ev-select
            v-model="store.wizardStep"
            label="Wizard step"
            :options="['basics', 'core-routers', 'wan', 'teams', 'links', 'config-summary', 'provision-result']"
          />
        </div>
      </div>

      <div class="row">
        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-if="store.wizardStep === 'device-state'">
          <status-device
            :device="store.device"
            :deviceState="store.loadStates.device"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'basics'">
          <form-basics
            :initialData="store.connection.basics"
            @update="setBasics"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'core-routers'">
          <form-core-routers
            :initialData="store.connection.coreRouters"
            @update="setCoreRouters"
            @back="store.wizardStep = 'basics'"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'checking-cores'">
          <status-cores
            :cores="store.connection.coreRouters"
            :coreState="coreState"
            @next="store.wizardStep = 'wan'"
            @back="store.wizardStep = 'core-routers'"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'wan'">
          <form-wan-interface
            :interfaces="store.device.interfaces"
            :initialData="store.connection.wan"
            @update="setWan"
            @back="store.wizardStep = 'core-routers'"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'teams'">
          <form-teams
            :initialData="store.connection.teams"
            @update="setTeams"
            @back="store.wizardStep = 'wan'"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'links'">
          <form-links
            :interfaces="store.device.interfaces"
            :usedInterfaces="usedInterfaces"
            @update="setLinks"
            @back="store.wizardStep = 'teams'"
          />
        </div>

        <div class="col-md-12" v-else-if="store.wizardStep === 'config-summary'">
          <config-summary
            :preparedConfig="store.preparedConfig"
            :preparedConfigState="store.loadStates.preparedConfig"
            @back="store.wizardStep = 'links'"
            @provision="provisionDevice"
          />
        </div>

        <div class="col-md-6" :class='{"col-md-offset-3": !debug}' v-else-if="store.wizardStep === 'provision-result'">
          <provision-status
            :loadState="store.loadStates.provision"
          />
        </div>

        <div class="col-md-6" v-if="debug">
          <pre>{{ JSON.stringify(store, null, 2) }}</pre>
        </div>
        <div style="height: 300px"></div>
      </div>

    </div>
  `,
  created() {
    getDeviceInfo()
      .then(() => (STORE.wizardStep = "basics"))
  },
  computed: {
    coreState() {
      return {
        primary: STORE.loadStates.primaryCore,
        secondary: STORE.loadStates.secondaryCore
      };
    },
    usedInterfaces() {
      return {
        [STORE.connection.wan.interface]: "WAN"
      };
    }
  },
  methods: {
    setBasics(data) {
      STORE.connection.basics = data;
      STORE.wizardStep = "core-routers";
    },
    setCoreRouters(data) {
      STORE.connection.coreRouters = data;
      STORE.wizardStep = "checking-cores";
      Promise.all([
        getPrimaryCoreDetails(STORE.connection.coreRouters.primaryIp),
        getSecondaryCoreDetails(STORE.connection.coreRouters.secondaryIp)
      ]).then(() => (STORE.wizardStep = "wan"));
    },
    setWan(data) {
      STORE.connection.wan = data;
      STORE.wizardStep = "teams";
    },
    setTeams(data) {
      STORE.connection.teams = data;
      STORE.wizardStep = "links";
    },
    setLinks(data) {
      STORE.connection.links = data;
      STORE.wizardStep = "config-summary";
      getPreparedConfig(STORE.connection);
    },
    provisionDevice() {
      STORE.wizardStep = "provision-result";
      actionProvisionDevice(STORE.preparedConfig);
    },
    setDummyConnectionData
  }
});

function setDummyConnectionData() {
  STORE.connection = {
    basics: {
      name: "dummyConnection",
      eviewId: "54654",
      deviceAsset: "en43634"
    },
    coreRouters: {
      primaryIp: "8.8.8.8",
      secondaryIp: "8.8.8.4"
    },
    wan: {
      interface: "eth0",
      subnet: "255.255.255.252",
      ip: "1.1.1.1"
    },
    teams: {
      primary: {
        teamIpCore: "172.16.0.1",
        teamIpEvx: "172.16.0.2"
      },
      secondary: {
        teamIpCore: "172.17.0.1",
        teamIpEvx: "172.17.0.2"
      }
    },
    links: [
      {
        linkNumber: 1,
        iface: "eth1"
      },
      {
        linkNumber: 2,
        iface: "eth2"
      }
    ]
  };
}

function develop() {
  STORE.develop = !STORE.develop;
}
