Vue.component("ev-input", {
  props: {
    label: String,
    type: String,
    help: String,
    focus: Boolean,
    value: String,
    valid: Object,
    disabled: Boolean
  },
  data() {
    return { id: "" };
  },
  template: `
    <div class="form-group" :class="{'has-error': valid && !valid.valid, 'has-success': valid && valid.valid && value !== ''}">
      <label :for="id">{{ label }}</label>
      <input
        :value="value"
        @input="updateValue($event.target.value)"
        :type="type || 'text'"
        class="form-control"
        :id="id"
        :disabled="disabled"
      >
      <p class="help-block">{{ help }} <span v-if="valid && valid.message">({{ valid.message }})</span></p>
    </div>
  `,
  beforeMount() {
    this.id = "ev-select-" + Math.floor(Math.random() * 10000);
  },
  mounted() {
    if (this.focus === true) {
      this.$el.children[1].focus();
    }
  },
  methods: {
    updateValue(value) {
      this.$emit("input", value);
    }
  }
});

Vue.component("ev-select", {
  props: ["label", "value", "options", "help", "valid", "focus"],
  data() {
    return { id: "" };
  },
  template: `
    <div class="form-group" :class="{'has-error': valid && !valid.valid, 'has-success': valid && valid.valid && value !== ''}">
      <label :for="id">{{ label }}</label>
      <select class="form-control" :value="value" @input="updateValue($event.target.value)" :id="id">
        <option v-for="o in formattedOptions" :value="o.value">{{ o.text }}</option>
      </select>
      <p class="help-block">{{ help }} <span v-if="valid && valid.message">({{ valid.message }})</span></p>
    </div>
  `,
  beforeMount() {
    this.id = "ev-select-" + Math.floor(Math.random() * 10000);
  },
  mounted() {
    if (this.focus === true) {
      this.$el.children[1].focus();
    }
  },
  computed: {
    formattedOptions() {
      return this.options.map(
        item =>
          typeof item === "string" || typeof item === "number"
            ? { value: item, text: item }
            : item
      );
    }
  },
  methods: {
    updateValue(value) {
      this.$emit("input", value);
    }
  }
});
