V = (function() {
  const VALID = {
    valid: true
  };

  function invalid(msg) {
    return {
      valid: false,
      message: msg
    };
  }

  function isPressent(value) {
    return value !== null && value !== undefined && value !== "";
  }

  function testWhenPressent(fn, invalidMessage) {
    return (value, formData) =>
      !isPressent(value) || fn(value, formData)
        ? VALID
        : invalid(invalidMessage);
  }

  const regex = (regex, message = "Incorrect format") =>
    testWhenPressent(value => regex.test(value), message);

  function ipStringToNumber(ip) {
    var _a = ip.split(".").map(Number),
      oct1 = _a[0],
      oct2 = _a[1],
      oct3 = _a[2],
      oct4 = _a[3];
    return oct1 * 16777216 + oct2 * 65536 + oct3 * 256 + oct4;
  }

  const V = {
    VALID,

    invalid,

    createTest(rules) {
      return (value, dataObject) =>
        STORE.disableValidation === true
          ? VALID
          : rules.reduce(
              (result, rule) =>
                result.valid ? rule(value, dataObject) : result,
              VALID
            );
    },

    createValiditor(shape) {
      const keys = Object.keys(shape);

      const tests = keys.map(key => ({
        key: key,
        test: V.createTest(shape[key])
      }));

      return objectValue =>
        tests.reduce(
          (results, { key, test }) => {
            const result = test(objectValue[key], objectValue);
            results[key] = result;
            results._allValid = results._allValid && result.valid;
            return results;
          },
          { _allValid: true }
        );
    },

    test: testWhenPressent,

    required: value =>
      isPressent(value) ? VALID : invalid("This is required"),

    regex: regex,

    integer: regex(/^[0-9]*$/, "Must be a number"),

    alphaNumeric: regex(/^[A-Za-z0-9]*$/),

    ipV4: regex(
      /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/,
      "Must be an IP"
    ),

    ipUsableIn: subnetKey =>
      testWhenPressent((value, dataObj) => {
        const subnet = dataObj[subnetKey];
        if (subnet === "255.255.255.255") return true;

        const subnetSize =
          ipStringToNumber("255.255.255.255") + 1 - ipStringToNumber(subnet);

        const indexInSubnet = ipStringToNumber(value) % subnetSize;

        return indexInSubnet !== 0 && indexInSubnet !== subnetSize - 1;
      }, "IP need to be usable. Not network/broadcast"),

    differentFrom: key =>
      testWhenPressent(
        (value, dataObj) => value !== dataObj[key],
        "Values need to be different"
      )
  };

  return V;
})();

const createValiditor = createRules => V.createValiditor(createRules(V));
