const FormConnectionId = Vue.component("form-basics", {
  props: ["initialData", "getState"],
  data() {
    return {
      formData: this.getDefault()
    };
  },
  template: `
    <form @submit.prevent="onSubmit">
      <h2>Connection</h2>
      <ev-input
        label='Connection name'
        v-model.trim='formData.name'
        :valid='validState.name'
        help='Short and identifiable. No spaces'
        focus
      />
      <ev-input
        label='eViewLive Id'
        v-model.trim='formData.eviewId'
        :valid='validState.eviewId'
        help='eView connection id'
      />
      <ev-input
        label='EVX asset ref'
        v-model.trim='formData.deviceAsset'
        :valid='validState.deviceAsset'
        help='e.g. EN6123'
      />
      <input
        class="btn btn-primary pull-right"
        type="submit"
        value="next"
        :disabled="!validState._allValid"
      />
    </form>
  `,
  methods: {
    getDefault() {
      return Object.assign(
        {
          name: "",
          eviewId: "",
          deviceAsset: ""
        },
        this.initialData
      );
    },

    reset() {
      this.formData = this.getDefault();
    },

    onSubmit() {
      this.$emit("update", Object.assign({}, this.formData));
    },

    validitor: createValiditor(V => ({
      name: [V.required, V.alphaNumeric],
      eviewId: [V.required, V.integer],
      deviceAsset: [V.required, V.regex(/^en[0-9]{4,}$/i)] // e.g. en6024
    }))
  },
  computed: {
    validState() {
      return this.validitor(this.formData);
    }
  }
});
