Vue.component("config-summary", {
  props: ["preparedConfig", "preparedConfigState"],
  data() {
    return {
      display: "formatted"
    };
  },
  template: `
    <div>
      <h2>Summary</h2>
      <div v-if="hasLoadError">
        <h3>Load Error</h3>
        <p>{{ errorMessage }}</p>
      </div>

      <div v-else-if="!hasLoaded">
        <p>Please wait</p>
      </div>

      <div v-else>
        <ul class="nav nav-tabs">
          <li role="presentation" :class="{active: display === 'formatted' }"><a href="#" @click.prevent="display = 'formatted'">Formatted</a></li>
          <li role="presentation" :class="{active: display === 'raw' }"><a href="#" @click.prevent="display = 'raw'">Raw</a></li>
        </ul>

        <pre v-if="display === 'raw'">{{ JSON.stringify(preparedConfig, null, 2) }}</pre>
        <div v-else>
          <div style="height: 20px;"></div>
          <div class="row">
            <div class="col-md-4">
              <h4>Connection</h4>
              <dl class="dl-horizontal">
                <dt>Name</dt>
                <dd>{{basics.name}}</dd>

                <dt>eView id</dt>
                <dd>{{basics.id}}</dd>

                <dt>Device asset</dt>
                <dd>{{basics.asset}}</dd>

                <dt>Link count</dt>
                <dd>{{ links.length }}</dd>
              </dl>

              <h4>WAN</h4>
              <dl class="dl-horizontal">
                <dt>Interface</dt>
                <dd>{{primary.wan.interface}}</dd>

                <dt>IP</dt>
                <dd>{{primary.wan.ip}}</dd>

                <dt>Subnet</dt>
                <dd>{{primary.wan.subnet}}</dd>
              </dl>
            </div>

            <div class="col-md-4">
              <h4>Core and Team</h4>
              <table class="table table-bordered">
                <thead>
                  <tr>
                    <td></td>
                    <td>Primary</td>
                    <td>Secondary</td>
                  </tr>
                </thead>
                <tbody>
                  <tr>
                    <td><strong>Core</strong></td>
                    <td></td>
                    <td></td>
                  </tr>
                  <tr>
                    <td>IP</td>
                    <td>{{primary.coreIp}}</td>
                    <td>{{secondary.coreIp}}</td>
                  </tr>
                  <tr>
                    <td><strong>Team</strong></td>
                    <td></td>
                    <td></td>
                  </tr>
                  <tr>
                    <td>Name</td>
                    <td>{{primary.team.name}}</td>
                    <td>{{secondary.team.name}}</td>
                  </tr>
                  <tr>
                    <td>Core IP</td>
                    <td>{{primary.team.ip.core}}</td>
                    <td>{{secondary.team.ip.core}}</td>
                  </tr>
                  <tr>
                    <td>EVX IP</td>
                    <td>{{primary.team.ip.evx}}</td>
                    <td>{{secondary.team.ip.evx}}</td>
                  </tr>
                </tbody>
              </table>
            </div>

            <div class="col-md-4">
              <h4>Links</h4>
              <table class="table table-bordered">
                <thead>
                  <tr>
                    <td></td>
                    <td>Primary</td>
                    <td>Secondary</td>
                  </tr>
                </thead>
                <tbody>
                  <template v-for="link in links">
                    <tr>
                      <td><strong>Link {{link.primaryLink.port}}: {{link.primaryLink.interface}}</strong></td>
                      <td></td>
                      <td></td>
                    </tr>
                    <tr>
                      <td>Name</td>
                      <td>{{link.primaryLink.name}}</td>
                      <td>{{link.secondaryLink.name}}</td>
                    </tr>
                    <tr>
                      <td>UDP port</td>
                      <td>{{link.primaryLink.udp}}</td>
                      <td>{{link.secondaryLink.udp}}</td>
                    </tr>
                    <tr></tr>
                  </template>
                </tbody>
              </table>
            </div>
          </div>
        </div>

        <div class="text-center">
          <p class="text-help">Check the config details above before provisioning</p>
          <input
            class="btn btn-success btn-lg"
            type="button"
            value="Provision"
            @click="$emit('provision')"
          />
        </div>
      </div>

      <input
        type="button"
        class="btn btn-default"
        value="back"
        @click="$emit('back')"
      />
    </div>
  `,
  computed: {
    hasLoaded() {
      const { preparedConfig } = this;
      return this.preparedConfigState.state === LOAD_STATES.LOADED && preparedConfig.connection;
    },
    hasLoadError() {
      return this.preparedConfigState.state === LOAD_STATES.LOAD_ERROR;
    },
    errorMessage() {
      const error = this.preparedConfigState.error;

      if (!error || error.message === undefined) {
        return "";
      }

      return error.message;
    },
    primary() {
      const { preparedConfig } = this;
      return preparedConfig.connection.primary;

    },
    secondary() {
      const { preparedConfig } = this;
      return preparedConfig.connection.secondary;
    },
    basics() {
      const { primary } = this;

      return {
        name: primary.name,
        id: primary.id,
        asset: primary.asset
      };
    },
    links() {
      const { primary, secondary } = this;
      return primary.links.map((primaryLink, index) => ({
        primaryLink,
        secondaryLink: secondary.links[index]
      }));
    }
  }
});
