const loadState = {
  props: ["loadState"],
  template: `
    <span :class="className">{{message}}</span>
  `,
  computed: {
    message() {
      const { loadState } = this;
      switch (loadState.state) {
        case LOAD_STATES.REQUESTED:
          return "processing";

        case LOAD_STATES.LOADED:
          return "SUCCESS";

        case LOAD_STATES.LOAD_ERROR:
          return "ERROR";
      }
    },
    className() {
      const { loadState } = this;
      switch (loadState.state) {
        case LOAD_STATES.LOADED:
          return "text-success";

        case LOAD_STATES.LOAD_ERROR:
          return "text-danger";
      }
    }
  }
};

Vue.component("status-cores", {
  props: {
    cores: {
      type: Object
    },
    coreState: {
      type: Object
    }
  },
  template: `
    <div>
      <h1>Checking Cores</h1>

      <h2>Primary ({{ cores.primaryIp }}) <load-state :loadState="coreState.primary"/></h2>
      <p v-if="coreState.primary.error && coreState.primary.error.message">Error Message: {{ coreState.primary.error.message }}</p>

      <h2>Secondary ({{ cores.secondaryIp }}) <load-state :loadState="coreState.secondary"/></h2>
      <p v-if="coreState.secondary.error && coreState.secondary.error.message">Error Message: {{ coreState.secondary.error.message }}</p>

      <div v-if="hasError">
        <p>There have been errors connecting to one or both core routers.</p>
        <p>Please check the IPs and try again.</p>
      </div>

      <div v-if="allLoaded">
        <p>Successfuly connected to both core routers.</p>
        <p>Please continue.</p>
      </div>

      <form>
        <input
          type="button"
          class="btn btn-primary"
          value="back"
          @click="$emit('back')"
        />
        <input
          class="btn btn-primary pull-right"
          type="submit"
          value="next"
          :disabled="!allLoaded"
        />
      </form>
    </div>
  `,
  components: {
    loadState
  },
  computed: {
    allLoaded() {
      const { coreState } = this;

      return (
        coreState.primary === LOAD_STATES.LOADED &&
        coreState.secondary === LOAD_STATES.LOADED
      );
    },
    hasError() {
      const { coreState } = this;

      return (
        coreState.primary === LOAD_STATES.LOAD_ERROR ||
        coreState.secondary === LOAD_STATES.LOAD_ERROR
      );
    }
  }

  // mounted() {

  // }
});
