Vue.component("form-teams", {
  props: ["initialData"],
  data() {
    return {
      formData: {
        primaryIpEvx: this.initialData.primary.teamIpCore
      }
    };
  },
  template: `
    <form @submit.prevent="onSubmit">
      <h2>Teams</h2>

      <ev-input
        label="Primary Core IP"
        v-model.trim="formData.primaryIpEvx"
        :valid='validState.primaryIpEvx'
        help="e.g. 172.16.0.1"
        :focus="true"
      />
      <ev-input
        label="Primary EVX IP"
        :value="primaryIpEvx"
        help="Auto Calculated from Core Team IP."
        :disabled="true"
      />

      <ev-input
        label="Secondary Core IP"
        :value="secondaryIpCore"
        :disabled="true"
      />
      <ev-input
        label="Secondary EVX IP"
        :value="secondaryIpEvx"
        :disabled="true"
      />

      <input
        type="button"
        class="btn btn-primary"
        value="back"
        @click="$emit('back')"
      />
      <input
        class="btn btn-primary pull-right"
        type="submit"
        value="next"
        :disabled="!validState._allValid"
      />
    </form>
  `,
  methods: {
    validitor: createValiditor(V => ({
      primaryIpEvx: [V.required, V.ipV4, V.differentFrom("teamIpEvx")]
    })),
    onSubmit() {
      const { formData, primaryIpEvx, secondaryIpCore, secondaryIpEvx } = this;

      this.$emit("update", {
        primary: {
          teamIpCore: formData.primaryIpEvx,
          teamIpEvx: primaryIpEvx
        },
        secondary: {
          teamIpCore: secondaryIpCore,
          teamIpEvx: secondaryIpEvx
        }
      });
    }
  },
  computed: {
    validState() {
      return this.validitor(this.formData);
    },
    primaryIpEvx() {
      const { validState, formData } = this;

      if (validState.primaryIpEvx.valid === false) {
        return "";
      }
      return ipNumberToString(ipStringToNumber(formData.primaryIpEvx) + 1);
    },
    secondaryIpCore() {
      const { validState, formData } = this;

      if (validState.primaryIpEvx.valid === false) {
        return "";
      }

      return ipNumberToString(
        ipStringToNumber(formData.primaryIpEvx) + ipStringToNumber("0.1.0.0")
      );
    },
    secondaryIpEvx() {
      const { validState, formData } = this;

      if (validState.primaryIpEvx.valid === false) {
        return "";
      }

      return ipNumberToString(
        ipStringToNumber(formData.primaryIpEvx) + ipStringToNumber("0.1.0.1")
      );
    }
  }
});
