function ipStringToNumber(ip) {
  var _a = ip.split(".").map(Number),
    oct1 = _a[0],
    oct2 = _a[1],
    oct3 = _a[2],
    oct4 = _a[3];
  return oct1 * 16777216 + oct2 * 65536 + oct3 * 256 + oct4;
}

function ipNumberToString(num) {
    var oct4 = num & 255;
    var oct3 = (num >>> 8) & 255;
    var oct2 = (num >>> 16) & 255;
    var oct1 = (num >>> 24);
    return oct1 + "." + oct2 + "." + oct3 + "." + oct4;
}

const FormWanInterface = Vue.component("form-wan-interface", {
  props: ["initialData", "interfaces"],
  data() {
    return {
      formData: Object.assign(
        {
          interface: "eth0",
          subnet: "",
          ip: ""
        },
        this.initialData
      ),
      subnets: [
        {
          value: "255.255.255.252",
          text: "255.255.255.252 (/30)"
        },
        {
          value: "255.255.255.248",
          text: "255.255.255.248 (/29)"
        },
        {
          value: "255.255.255.240",
          text: "255.255.255.240 (/28)"
        },
        {
          value: "255.255.255.224",
          text: "255.255.255.224 (/27)"
        }
      ]
    };
  },
  template: `
    <form @submit.prevent="onSubmit">
      <h2>Wan</h2>
      <ev-select
        label="interface"
        :options="interfaces"
        v-model="formData.interface"
        :focus="true"
      />
      <ev-select
        label="Subnet"
        v-model="formData.subnet"
        :options="subnets"
        help="e.g. 255.255.255.252"
      />
      <ev-input
        label="Public IP"
        v-model.trim="formData.ip"
        :valid='validState.ip'
        help="CPE/Gateway IP"
      />


      <input
        type="button"
        class="btn btn-primary"
        value="back"
        @click="$emit('back')"
      />
      <input
        class="btn btn-primary pull-right"
        type="submit"
        value="next"
        :disabled="!validState._allValid"
      />
    </form>
  `,
  methods: {
    validitor: createValiditor(V => ({
      ip: [V.required, V.ipV4, V.ipUsableIn('subnet')]
    })),
    onSubmit() {
      this.$emit("update", Object.assign({}, this.formData));
    }
  },
  computed: {
    validState() {
      return this.validitor(this.formData);
    }
  }
});
